@@ -202,7 +202,7 @@ func TestNewHTTPClient(t *testing.T) {
 
 type tinyConfig map[string]string
 
-func (c tinyConfig) AuthToken(host string) (string, string) {
+func (c tinyConfig) Token(host string) (string, string) {
 	return c[fmt.Sprintf("%s:%s", host, "oauth_token")], "oauth_token"
 }
 
