@@ -29,30 +29,33 @@ const (
 // newPortsCmd returns a Cobra "ports" command that displays a table of available ports,
 // according to the specified flags.
 func newPortsCmd(app *App) *cobra.Command {
-	var codespace string
-	var exporter cmdutil.Exporter
+	var (
+		selector *CodespaceSelector
+		exporter cmdutil.Exporter
+	)
 
 	portsCmd := &cobra.Command{
 		Use:   "ports",
 		Short: "List ports in a codespace",
 		Args:  noArgsConstraint,
 		RunE: func(cmd *cobra.Command, args []string) error {
-			return app.ListPorts(cmd.Context(), codespace, exporter)
+			return app.ListPorts(cmd.Context(), selector, exporter)
 		},
 	}
 
-	portsCmd.PersistentFlags().StringVarP(&codespace, "codespace", "c", "", "Name of the codespace")
+	selector = AddCodespaceSelector(portsCmd, app.apiClient)
+
 	cmdutil.AddJSONFlags(portsCmd, &exporter, portFields)
 
-	portsCmd.AddCommand(newPortsForwardCmd(app))
-	portsCmd.AddCommand(newPortsVisibilityCmd(app))
+	portsCmd.AddCommand(newPortsForwardCmd(app, selector))
+	portsCmd.AddCommand(newPortsVisibilityCmd(app, selector))
 
 	return portsCmd
 }
 
 // ListPorts lists known ports in a codespace.
-func (a *App) ListPorts(ctx context.Context, codespaceName string, exporter cmdutil.Exporter) (err error) {
-	codespace, err := getOrChooseCodespace(ctx, a.apiClient, codespaceName)
+func (a *App) ListPorts(ctx context.Context, selector *CodespaceSelector, exporter cmdutil.Exporter) (err error) {
+	codespace, err := selector.Select(ctx)
 	if err != nil {
 		return err
 	}
@@ -65,9 +68,11 @@ func (a *App) ListPorts(ctx context.Context, codespaceName string, exporter cmdu
 	}
 	defer safeClose(session, &err)
 
-	a.StartProgressIndicatorWithLabel("Fetching ports")
-	ports, err := session.GetSharedServers(ctx)
-	a.StopProgressIndicator()
+	var ports []*liveshare.Port
+	err = a.RunWithProgress("Fetching ports", func() (err error) {
+		ports, err = session.GetSharedServers(ctx)
+		return
+	})
 	if err != nil {
 		return fmt.Errorf("error getting ports of shared servers: %w", err)
 	}
@@ -218,21 +223,14 @@ func getDevContainer(ctx context.Context, apiClient apiClient, codespace *api.Co
 	return ch
 }
 
-func newPortsVisibilityCmd(app *App) *cobra.Command {
+func newPortsVisibilityCmd(app *App, selector *CodespaceSelector) *cobra.Command {
 	return &cobra.Command{
 		Use:     "visibility <port>:{public|private|org}...",
 		Short:   "Change the visibility of the forwarded port",
 		Example: "gh codespace ports visibility 80:org 3000:private 8000:public",
 		Args:    cobra.MinimumNArgs(1),
 		RunE: func(cmd *cobra.Command, args []string) error {
-			codespace, err := cmd.Flags().GetString("codespace")
-			if err != nil {
-				// should only happen if flag is not defined
-				// or if the flag is not of string type
-				// since it's a persistent flag that we control it should never happen
-				return fmt.Errorf("get codespace flag: %w", err)
-			}
-			return app.UpdatePortVisibility(cmd.Context(), codespace, args)
+			return app.UpdatePortVisibility(cmd.Context(), selector, args)
 		},
 	}
 }
@@ -261,13 +259,13 @@ func (e *ErrUpdatingPortVisibility) Unwrap() error {
 
 var errUpdatePortVisibilityForbidden = errors.New("organization admin has forbidden this privacy setting")
 
-func (a *App) UpdatePortVisibility(ctx context.Context, codespaceName string, args []string) (err error) {
+func (a *App) UpdatePortVisibility(ctx context.Context, selector *CodespaceSelector, args []string) (err error) {
 	ports, err := a.parsePortVisibilities(args)
 	if err != nil {
 		return fmt.Errorf("error parsing port arguments: %w", err)
 	}
 
-	codespace, err := getOrChooseCodespace(ctx, a.apiClient, codespaceName)
+	codespace, err := selector.Select(ctx)
 	if err != nil {
 		return err
 	}
@@ -280,40 +278,40 @@ func (a *App) UpdatePortVisibility(ctx context.Context, codespaceName string, ar
 
 	// TODO: check if port visibility can be updated in parallel instead of sequentially
 	for _, port := range ports {
-		a.StartProgressIndicatorWithLabel(fmt.Sprintf("Updating port %d visibility to: %s", port.number, port.visibility))
+		err := a.RunWithProgress(fmt.Sprintf("Updating port %d visibility to: %s", port.number, port.visibility), func() (err error) {
+			// wait for success or failure
+			g, ctx := errgroup.WithContext(ctx)
+			ctx, cancel := context.WithTimeout(ctx, 30*time.Second)
+			defer cancel()
 
-		// wait for success or failure
-		g, ctx := errgroup.WithContext(ctx)
-		ctx, cancel := context.WithTimeout(ctx, 30*time.Second)
-		defer cancel()
+			g.Go(func() error {
+				updateNotif, err := session.WaitForPortNotification(ctx, port.number, liveshare.PortChangeKindUpdate)
+				if err != nil {
+					return fmt.Errorf("error waiting for port %d to update: %w", port.number, err)
 
-		g.Go(func() error {
-			updateNotif, err := session.WaitForPortNotification(ctx, port.number, liveshare.PortChangeKindUpdate)
-			if err != nil {
-				return fmt.Errorf("error waiting for port %d to update: %w", port.number, err)
-
-			}
-			if !updateNotif.Success {
-				if updateNotif.StatusCode == http.StatusForbidden {
-					return newErrUpdatingPortVisibility(port.number, port.visibility, errUpdatePortVisibilityForbidden)
 				}
-				return newErrUpdatingPortVisibility(port.number, port.visibility, errors.New(updateNotif.ErrorDetail))
+				if !updateNotif.Success {
+					if updateNotif.StatusCode == http.StatusForbidden {
+						return newErrUpdatingPortVisibility(port.number, port.visibility, errUpdatePortVisibilityForbidden)
+					}
+					return newErrUpdatingPortVisibility(port.number, port.visibility, errors.New(updateNotif.ErrorDetail))
 
-			}
-			return nil // success
+				}
+				return nil // success
+			})
+
+			g.Go(func() error {
+				err := session.UpdateSharedServerPrivacy(ctx, port.number, port.visibility)
+				if err != nil {
+					return fmt.Errorf("error updating port %d to %s: %w", port.number, port.visibility, err)
+				}
+				return nil
+			})
+
+			// wait for success or failure
+			err = g.Wait()
+			return
 		})
-
-		g.Go(func() error {
-			err := session.UpdateSharedServerPrivacy(ctx, port.number, port.visibility)
-			if err != nil {
-				return fmt.Errorf("error updating port %d to %s: %w", port.number, port.visibility, err)
-			}
-			return nil
-		})
-
-		// wait for success or failure
-		err := g.Wait()
-		a.StopProgressIndicator()
 		if err != nil {
 			return err
 		}
@@ -347,32 +345,24 @@ func (a *App) parsePortVisibilities(args []string) ([]portVisibility, error) {
 
 // NewPortsForwardCmd returns a Cobra "ports forward" subcommand, which forwards a set of
 // port pairs from the codespace to localhost.
-func newPortsForwardCmd(app *App) *cobra.Command {
+func newPortsForwardCmd(app *App, selector *CodespaceSelector) *cobra.Command {
 	return &cobra.Command{
 		Use:   "forward <remote-port>:<local-port>...",
 		Short: "Forward ports",
 		Args:  cobra.MinimumNArgs(1),
 		RunE: func(cmd *cobra.Command, args []string) error {
-			codespace, err := cmd.Flags().GetString("codespace")
-			if err != nil {
-				// should only happen if flag is not defined
-				// or if the flag is not of string type
-				// since it's a persistent flag that we control it should never happen
-				return fmt.Errorf("get codespace flag: %w", err)
-			}
-
-			return app.ForwardPorts(cmd.Context(), codespace, args)
+			return app.ForwardPorts(cmd.Context(), selector, args)
 		},
 	}
 }
 
-func (a *App) ForwardPorts(ctx context.Context, codespaceName string, ports []string) (err error) {
+func (a *App) ForwardPorts(ctx context.Context, selector *CodespaceSelector, ports []string) (err error) {
 	portPairs, err := getPortPairs(ports)
 	if err != nil {
 		return fmt.Errorf("get port pairs: %w", err)
 	}
 
-	codespace, err := getOrChooseCodespace(ctx, a.apiClient, codespaceName)
+	codespace, err := selector.Select(ctx)
 	if err != nil {
 		return err
 	}
