@@ -436,23 +436,32 @@ func (m *Manager) installBin(repo ghrepo.Interface, target string) error {
 	}
 
 	if !m.dryRunMode {
-		manifestPath := filepath.Join(targetDir, manifestName)
-
-		f, err := os.OpenFile(manifestPath, os.O_WRONLY|os.O_CREATE|os.O_TRUNC, 0600)
-		if err != nil {
-			return fmt.Errorf("failed to open manifest for writing: %w", err)
-		}
-		defer f.Close()
-
-		_, err = f.Write(bs)
-		if err != nil {
-			return fmt.Errorf("failed write manifest file: %w", err)
+		if err := writeManifest(targetDir, manifestName, bs); err != nil {
+			return err
 		}
 	}
 
 	return nil
 }
 
+func writeManifest(dir, name string, data []byte) (writeErr error) {
+	path := filepath.Join(dir, name)
+	var f *os.File
+	if f, writeErr = os.OpenFile(path, os.O_WRONLY|os.O_CREATE|os.O_TRUNC, 0600); writeErr != nil {
+		writeErr = fmt.Errorf("failed to open manifest for writing: %w", writeErr)
+		return
+	}
+	defer func() {
+		if err := f.Close(); writeErr == nil && err != nil {
+			writeErr = err
+		}
+	}()
+	if _, writeErr = f.Write(data); writeErr != nil {
+		writeErr = fmt.Errorf("failed write manifest file: %w", writeErr)
+	}
+	return
+}
+
 func (m *Manager) installGit(repo ghrepo.Interface, target string) error {
 	protocol, _ := m.config.GetOrDefault(repo.RepoHost(), "git_protocol")
 	cloneURL := ghrepo.FormatRemoteURL(repo, protocol)
@@ -708,7 +717,7 @@ func (m *Manager) goBinScaffolding(name string) error {
 		return err
 	}
 
-	host, _ := m.config.DefaultHost()
+	host, _ := m.config.Authentication().DefaultHost()
 
 	currentUser, err := api.CurrentLoginName(api.NewClientFromHTTP(m.client), host)
 	if err != nil {
