@@ -155,7 +155,7 @@ func gardenRun(opts *GardenOptions) error {
 			if err != nil {
 				return err
 			}
-			hostname, _ := cfg.DefaultHost()
+			hostname, _ := cfg.Authentication().DefaultHost()
 			currentUser, err := api.CurrentLoginName(apiClient, hostname)
 			if err != nil {
 				return err
