@@ -12,6 +12,7 @@ import (
 	"github.com/AlecAivazis/survey/v2"
 	"github.com/cli/cli/v2/api"
 	"github.com/cli/cli/v2/internal/ghrepo"
+	"github.com/cli/cli/v2/internal/prompter"
 	workflowShared "github.com/cli/cli/v2/pkg/cmd/workflow/shared"
 	"github.com/cli/cli/v2/pkg/iostreams"
 	"github.com/cli/cli/v2/pkg/prompt"
@@ -44,6 +45,23 @@ type Status string
 type Conclusion string
 type Level string
 
+var AllStatuses = []string{
+	"queued",
+	"completed",
+	"in_progress",
+	"requested",
+	"waiting",
+	"action_required",
+	"cancelled",
+	"failure",
+	"neutral",
+	"skipped",
+	"stale",
+	"startup_failure",
+	"success",
+	"timed_out",
+}
+
 var RunFields = []string{
 	"name",
 	"displayTitle",
@@ -284,6 +302,7 @@ type FilterOptions struct {
 	WorkflowID int64
 	// avoid loading workflow name separately and use the provided one
 	WorkflowName string
+	Status       string
 }
 
 // GetRunsWithFilter fetches 50 runs from the API and filters them in-memory
@@ -326,6 +345,9 @@ func GetRuns(client *api.Client, repo ghrepo.Interface, opts *FilterOptions, lim
 		if opts.Actor != "" {
 			path += fmt.Sprintf("&actor=%s", url.QueryEscape(opts.Actor))
 		}
+		if opts.Status != "" {
+			path += fmt.Sprintf("&status=%s", url.QueryEscape(opts.Status))
+		}
 	}
 
 	var result *RunsPayload
@@ -420,6 +442,29 @@ func GetJob(client *api.Client, repo ghrepo.Interface, jobID string) (*Job, erro
 	return &result, nil
 }
 
+// SelectRun prompts the user to select a run from a list of runs by using the recommended prompter interface
+func SelectRun(p prompter.Prompter, cs *iostreams.ColorScheme, runs []Run) (string, error) {
+	now := time.Now()
+
+	candidates := []string{}
+
+	for _, run := range runs {
+		symbol, _ := Symbol(cs, run.Status, run.Conclusion)
+		candidates = append(candidates,
+			// TODO truncate commit message, long ones look terrible
+			fmt.Sprintf("%s %s, %s (%s) %s", symbol, run.Title(), run.WorkflowName(), run.HeadBranch, preciseAgo(now, run.StartedTime())))
+	}
+
+	selected, err := p.Select("Select a workflow run", "", candidates)
+
+	if err != nil {
+		return "", err
+	}
+
+	return fmt.Sprintf("%d", runs[selected].ID), nil
+}
+
+// TODO: this should be deprecated in favor of SelectRun
 func PromptForRun(cs *iostreams.ColorScheme, runs []Run) (string, error) {
 	var selected int
 	now := time.Now()
@@ -449,16 +494,27 @@ func PromptForRun(cs *iostreams.ColorScheme, runs []Run) (string, error) {
 	return fmt.Sprintf("%d", runs[selected].ID), nil
 }
 
-func GetRun(client *api.Client, repo ghrepo.Interface, runID string) (*Run, error) {
+func GetRun(client *api.Client, repo ghrepo.Interface, runID string, attempt uint64) (*Run, error) {
 	var result Run
 
 	path := fmt.Sprintf("repos/%s/actions/runs/%s?exclude_pull_requests=true", ghrepo.FullName(repo), runID)
 
+	if attempt > 0 {
+		path = fmt.Sprintf("repos/%s/actions/runs/%s/attempts/%d?exclude_pull_requests=true", ghrepo.FullName(repo), runID, attempt)
+	}
+
 	err := client.REST(repo.RepoHost(), "GET", path, nil, &result)
 	if err != nil {
 		return nil, err
 	}
 
+	if attempt > 0 {
+		result.URL, err = url.JoinPath(result.URL, fmt.Sprintf("/attempts/%d", attempt))
+		if err != nil {
+			return nil, err
+		}
+	}
+
 	// Set name to workflow name
 	workflow, err := workflowShared.GetWorkflow(client, repo, result.WorkflowID)
 	if err != nil {
